#
# spec file for package perl-B-Keywords
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name B-Keywords
Name:           perl-B-Keywords
Version:        1.270.0
Release:        bp160.1.7
# 1.27 -> normalize -> 1.270.0
%define cpan_version 1.27
#Upstream:  2017-2021 Reini Urban, All rights reserved. This program is free software; you can redistribute it and/or modify it under the terms of either: a) the GNU General Public License as published by the Free Software Foundation; version 2, or b) the "Artistic License" which comes with Perl.
License:        Artistic-1.0 OR GPL-2.0-only
Summary:        Lists of reserved barewords and symbol names
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RU/RURBAN/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(B::Keywords) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
'B::Keywords' supplies several arrays of exportable keywords: '@Scalars',
'@Arrays', '@Hashes', '@Filehandles', '@Symbols', '@Functions',
'@Barewords', '@BarewordsExtra', '@TieIOMethods', '@UNIVERSALMethods' and
'@ExporterSymbols'.

The '@Symbols' array includes the contents of each of '@Scalars',
'@Arrays', '@Hashes', '@Functions' and '@Filehandles'.

Similarly, '@Barewords' adds a few non-function keywords and operators to
the '@Functions' array.

'@BarewordsExtra' adds a few barewords which are not in keywords.h.

All additions and modifications are welcome.

The perl parser uses a static list of keywords from _regen/keywords.pl_
which constitutes the strict list of keywords @Functions and @Barewords,
though some @Functions are not functions in the strict sense. Several
library functions use more special symbols, handles and methods.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sun Jun 23 2024 Tina Müller <tina.mueller@suse.com>
- updated to 1.270.0 (1.27)
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.27 2024-05-27 12:13 rurban
  - Add bareword __CLASS__ since 5.39.2
* Tue Jun 20 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.26
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.25 2023-06-19 15:16:08 rurban
  - Add Corinna keywords, new with Perl 5.38.0 (PR #8, @trwyant)
    ADJUST class field method
  1.26 2023-06-19 18:43 rurban
  - Updated README
* Wed Feb 23 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.24
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.24 2022-02-21 10:47:08 rurban
  - Fix for broken <archlibexp>/CORE/keywords.h test on system macOS
    (PR #5, @nega0)
  - finally added with 5.35.8 (RT #141406)
* Sun Oct 31 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.23
  see /usr/share/doc/packages/perl-B-Keywords/Changes
* Tue Feb 23 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.22
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.22 2021-02-22 09:42:18 rurban
  - add try/catch by Tom Wyant
* Wed Dec 18 2019 <timueller+perl@suse.de>
- updated to 1.21
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.21 2019-12-17 17:38:00 rurban
  - isa was added with 5.31.7
  - improved t/z_kwalitee.t
* Sat Feb 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.20
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.20 2019-02-15 11:03:00 rurban
  - extern was added with 5.29.0c
* Fri Aug 24 2018 coolo@suse.com
- updated to 1.19
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.19 Thu Aug 23 11:16:09 CEST 2018
  - our was added with 5.005_61
* Wed Feb  7 2018 coolo@suse.com
- updated to 1.18
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.17 Mon Jan 29 17:57:05 CET 2018 rurban
  - Added 5.27.8 changes, whereis/whereso is gone for good.
    There's still a chance for perl6 compat
  1.18 Mon Jan 29 18:09:23 CET 2018 rurban
  - Oops, forgot break
* Fri Dec 29 2017 coolo@suse.com
- updated to 1.16
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.16 Thu Dec 28 2017 rurban
  - Added 5.27.7 changes, RT #123948
  - Added cperl class keywords
  - Added keywords per version back to 5.004
* Sat Nov 14 2015 coolo@suse.com
- updated to 1.15
  see /usr/share/doc/packages/perl-B-Keywords/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.14
  see /usr/share/doc/packages/perl-B-Keywords/Changes
  1.14 rurban
  - removed err from Barewords, RT #102259 (Alex Efros a.k.a. Powerman)
* Mon Jun  3 2013 coolo@suse.com
- updated to 1.13
  - removed diag before each big t/11keywords.t loop
  - added suggested keywords from RT #62382:
  * _ and DATA to @FileHandles (the deprecated lowercase: stdin, stdout, stderr not),
    import unimport to @Functions,
    BINMODE CLEAR CLEARERR CLONE CLONE_SKIP CLOSE DELETE EOF
    ERROR EXISTS EXTEND FDOPEN FETCH FETCHSIZE FILENO FILL FIRSTKEY FLUSH
    GETC NEXTKEY OPEN POP POPPED PRINT PRINTF PUSH PUSHED READ READLINE
    SCALAR SEEK SETLINEBUF SHIFT SPLICE STORE STORESIZE SYSOPEN TELL
    TIEARRAY TIEHANDLE TIEHASH TIESCALAR UNREAD UNSHIFT UNTIE UTF8 WRITE to @TieIOMethods,
    can isa DOES VERSION to @UNIVERSALMethods,
    @EXPORT @EXPORT_OK @EXPORT_FAIL
    @EXPORT_TAGS _push_tags _rebuild_cache as_heavy export export_fail
    export_fail_in export_ok_tags export_tags export_to_level heavy_export
    heavy_export_ok_tags heavy_export_tags heavy_export_to_level
    heavy_require_version require_version  to @ExporterSymbols (Zsbán Ambrus)
  - Moved exp from @Barewords to @Functions
  - Added $^CHILD_ERROR_NATIVE $^GLOBAL_PHASE $^LAST_FH $^MATCH $^PREMATCH
    $^POSTMATCH $^UTF8CACHE $^WIN32_SLOPPY_STAT to @Scalars
  - Added English names for %%!, @F (perlrun) and @ARG for @_ (Zsbán Ambrus)
  - Added %%+ %%- (Zsbán Ambrus) and $LAST_SUBMATCH_RESULT
* Fri Feb 10 2012 coolo@suse.com
- updated to 1.12
  - Add new keywords for 5.16, __SUB__ and evalbytes.
  - Add new keyword fc (Unicode casefolding) for 5.16 added with commit 838f2281
  - added diag before each big t/11keywords.t loop
* Mon Jun 20 2011 coolo@novell.com
- fix license
* Mon Apr  4 2011 coolo@novell.com
- updated to 1.10
  - Fix typo in SYNOPSIS
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Wed Oct 21 2009 rschweikert@novell.com
- Add this file to project
- Add %%dir for B directory
- Change changelog to only include initial entry
- Package initial creation Mon Aug 31 2009
